package command;

import cli.CommandLineInterface;
import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.ParseException;

public class CommandSelector {

    private final CommandLineInterface commandLineInterface;
    private final String[] enteredCommand;

    public CommandSelector(String[] enteredCommand) {
        this.enteredCommand = enteredCommand;
        this.commandLineInterface = new CommandLineInterface();

    }

    public void executeCommand() {
        try {
            CommandLine userInput = commandLineInterface.getInput(enteredCommand);
            Command command;
            if (userInput.hasOption("new")) {
                command = createIssue(userInput.getOptionValues("new"));
            } else if (userInput.hasOption("init")) {
                command = init();
            } else if (userInput.hasOption("ls")) {
                command = ls(userInput.getOptionValues("ls"));
            } else if (userInput.hasOption("show")) {
                command = show(userInput.getOptionValue("show"));
            } else if (userInput.hasOption("comment")) {
                command = comment(userInput.getOptionValues("comment"));
            } else if (userInput.hasOption("update")) {
                command = update(userInput.getOptionValues("update"));
            } else if (userInput.hasOption("pull")) {
                command = pull(userInput.getOptionValue("pull"));
            } else if (userInput.hasOption("push")) {
                command = push(userInput.getOptionValue("push"));
            } else if (userInput.hasOption("tag")) {
                command = tag(userInput.getOptionValues("tag"));
            } else if (userInput.hasOption("delete")) {
                command = delete(userInput.getOptionValue("delete"));
            } else if(userInput.hasOption("watcher")){
                command = watcher(userInput.getOptionValues("watcher"));
            } else if(userInput.hasOption("assignee")){
                command = assignee(userInput.getOptionValues("assignee"));
            } else {
                commandLineInterface.help();
                command = nullCommand();
            }
            command.execute();

        } catch (ParseException e) {
            e.printStackTrace();
        }
    }

    private Command comment(String[] args) {
        return new CommandComment(args[0], args[1]);
    }

    private Command pull(String remote) {
        return new CommandPull(remote);
    }

    private Command push(String remote) {
        return new CommandPush(remote);
    }

    private Command init() {
        return new CommandInit();
    }

    private Command nullCommand() {
        return new CommandNull();
    }

    private Command createIssue(String[] args) {
        return new CommandCreate(args);
    }

    private Command ls(String[] args) {
        return new CommandLs(args);
    }

    private Command delete(String id) {
        return new CommandDelete(id);
    }

    private Command show(String id) {
        return new CommandShow(id);
    }

    private Command update(String[] args) {
        return new CommandUpdate(args);
    }

    private Command tag(String[] args) {
        return new CommandTag(args);
    }

    private Command assignee(String[] args) { return new CommandAssign(args);}

    private Command watcher(String[] args) { return new CommandWatcher(args);}

}
