package command;

import git.IssueRepo;

import java.io.IOException;

public final class CommandUpdate implements Command {

    private final String hash;
    private final String option;
    private final String data;

    CommandUpdate(String[] args) {
        this.hash = args[0];
        this.option = args[1];
        this.data = args[2];
    }

    @Override
    public void execute() {
        IssueRepo repo = new IssueRepo();
        repo.getIssues().forEach(issue -> {
            if (issue.getOriginalHash().equals(hash)) {
                String commitMessage = null;
                switch (option) {
                    case "title":
                        issue.setTitle(data);
                        issue.edited();
                        commitMessage = "title of " + hash + " updated";
                        System.out.println("Title updated");
                        break;
                    case "desc":
                        issue.setDescription(data);
                        issue.edited();
                        commitMessage = "description of " + hash + " updated";
                        System.out.println("Description updated");
                        break;
                    case "status":
                        if (data.equals("open")) {
                            issue.setStatus(true);
                            commitMessage = "opened issue " + hash;
                            System.out.println("Issue opened");
                        } else if (data.equals("close")) {
                            issue.setStatus(false);
                            commitMessage = "closed issue " + hash;
                            System.out.println("Issue closed");
                        }
                        issue.edited();
                        break;
                    default:
                        System.out.println("invalid option");
                        break;

                }
                if (commitMessage != null) {
                    try {
                        repo.updateIssues(issue, commitMessage);
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }

            }
        });

    }
}
