package command;

import git.IssueRepo;
import issueData.User;

import java.io.IOException;

public class CommandWatcher implements Command {

    private final String hash;
    private final String option;
    private final String name;
    private final String email;

    CommandWatcher(String[] args) {
        this.hash = args[0];
        this.option = args[1];
        this.name = args[2];
        this.email = args[3];
    }

    @Override
    public void execute() {
        IssueRepo repo = new IssueRepo();
        repo.getIssues().forEach(issue -> {
            if (issue.getOriginalHash().equals(hash)) {
                String commitMessage = null;
                switch (option) {
                    case "add":
                        issue.addWatcher(new User(name, email));
                        issue.edited();
                        commitMessage = "Watcher " + name + " " + email + "added to issue " + hash;
                        System.out.println("Watcher added");
                        break;
                    case "rm":
                        issue.removeWatcher(new User(name, email));
                        issue.edited();
                        commitMessage = "Watcher " + name + " " + email + "removed from issue " + hash;
                        System.out.println("Watcher removed");
                        break;
                    default:
                        System.out.println("invalid option");
                        break;

                }
                if (commitMessage != null) {
                    try {
                        repo.updateIssues(issue, commitMessage);
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
        });
    }
}
