package issueData;

import org.apache.commons.codec.digest.DigestUtils;

import java.util.*;

public class Issue {

    private List<Comment> comments;
    private Set<String> tags;
    private Set<User> assignees;
    private Set<User> watchers;
    private String title;
    private String description;
    private User creator;
    private String originalHash;
    private boolean status;
    private long creationTime;
    private long edited;

    public Issue(String title, String description) {
        this.title = title;
        this.description = description;
        this.status = true;
        long time = System.currentTimeMillis();
        this.creationTime = time;
        this.edited = time;
        this.originalHash = DigestUtils.sha256Hex(title + description + creationTime);
        this.comments = new ArrayList<>();
        this.tags = new HashSet<>();
        this.assignees = new HashSet<>();
        this.watchers = new HashSet<>();
    }

    public Issue() {
        comments = new ArrayList<>();
        tags = new HashSet<>();
        assignees = new HashSet<>();
        watchers = new HashSet<>();
    }

    public void edited() {
        edited = System.currentTimeMillis();
    }

    public long getCreationTime() {
        return creationTime;
    }

    public void setCreationTime(long creationTime) {
        this.creationTime = creationTime;
    }

    public String getTitle() {
        return this.title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getOriginalHash() {
        return originalHash;
    }

    public void setOriginalHash(String originalHash) {
        this.originalHash = originalHash;
    }

    public void addComment(Comment comment) {
        comments.add(comment);
    }

    public List<Comment> getComments() {
        return comments;
    }

    public void addWatcher(User user) {
        watchers.add(user);
    }

    public Set<User> getWatchers() {
        return watchers;
    }

    public void removeWatcher(User user) {
        watchers.remove(user);
    }

    public void setWatchers(Set<User> watchers) {this.watchers = watchers;}

    public void addAssignee(User user) {
        assignees.add(user);
    }

    public Set<User> getAssignees() {
        return assignees;
    }

    public void removeAssignee(User user) {
        assignees.remove(user);
    }

    public void setAssignees(Set<User> assignees) {this.assignees = assignees;}

    public void addTags(String tag) {
        List<String> strings = Arrays.asList(tag.split("\\s*,\\s*"));
        strings.forEach(t -> {
            if (!t.equals("")) {
                tags.add(t);
            }
        });
    }

    public void addTag(String tag) {
        tags.add(tag);
    }

    public void removeTag(String tag) {
        List<String> strings = Arrays.asList(tag.split("\\s*,\\s*"));
        strings.forEach(t -> {
            if (!t.equals("")) {
                tags.remove(t);
            }
        });
    }


    public Set<String> getTags() {
        return tags;
    }

    public void setTags(Set<String> tags) {
        this.tags = tags;
    }

    public long getEdited() {
        return edited;
    }

    public void setEdited(long edited) {
        this.edited = edited;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public User getCreator() {
        return creator;
    }

    public void setCreator(User creator) {
        this.creator = creator;
    }

    public boolean isOpen() {
        return status;
    }

    public void setStatus(boolean status) {
        this.status = status;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Issue issue = (Issue) o;
        return Objects.equals(originalHash, issue.originalHash);
    }

    @Override
    public int hashCode() {
        return Objects.hash(originalHash);
    }

    @Override
    public String toString() {
        return "Hash: " + originalHash + " Title: " + title;
    }

}
